⚠️ Version du module: 1.0

⭐️• Introduction :>

Le module PyBarLoad est un module, qui permet de faire des barres de chargements ! ( Personalisables ! ) 

⭐️• Authors :>

Katsu'hi, Prasax

⭐️• Utilisation :>

🌹 Bar de chargement :

Pybar.Bar(Durée, "texte de fin")